==> haskell-th-orphans-0.13.3-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-orphans
version: 0.13.3
id: th-orphans-0.13.3-JH0tGvKyTLXGgL9CeBHhV2
key: th-orphans-0.13.3-JH0tGvKyTLXGgL9CeBHhV2
license: BSD3
copyright: (c) Matt Morrow
maintainer: Michael Sloan <mgsloan at gmail>
stability: experimental
synopsis: Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.
category: Template Haskell
author: Matt Morrow
exposed: True
exposed-modules:
    Language.Haskell.TH.Instances
abi: bf037a4003a08069fc972ebf4416334e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/th-orphans-0.13.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/th-orphans-0.13.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/th-orphans-0.13.3
hs-libraries: HSth-orphans-0.13.3-JH0tGvKyTLXGgL9CeBHhV2
depends:
    base-4.9.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    template-haskell-2.11.0.0 th-lift-0.7.7-JuNRTOt9I9JCRNDoGbQTGn
    th-lift-instances-0.1.11-DLUWPVBm41gAHGhVdwx66v
    th-reify-many-0.1.6-Ad6sxWcevbB33rW4RqMPHJ
haddock-interfaces: /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html: /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-orphans-0.13.3-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-orphans
version: 0.13.3
id: th-orphans-0.13.3-6KB9kSUCs3A8Xi6hqirlC2
key: th-orphans-0.13.3-6KB9kSUCs3A8Xi6hqirlC2
license: BSD3
copyright: (c) Matt Morrow
maintainer: Michael Sloan <mgsloan at gmail>
stability: experimental
synopsis: Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.
category: Template Haskell
author: Matt Morrow
exposed: True
exposed-modules:
    Language.Haskell.TH.Instances
abi: a86a36554b1f510e5c8b2a4a4f3b8f6b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/th-orphans-0.13.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/th-orphans-0.13.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/th-orphans-0.13.3
hs-libraries: HSth-orphans-0.13.3-6KB9kSUCs3A8Xi6hqirlC2
depends:
    base-4.9.0.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    template-haskell-2.11.0.0 th-lift-0.7.7-JuNRTOt9I9JCRNDoGbQTGn
    th-lift-instances-0.1.11-1sD5YjoMgIx3ybpjdu7bXa
    th-reify-many-0.1.6-Ad6sxWcevbB33rW4RqMPHJ
haddock-interfaces: /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html: /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
